function populateTable(containersData) {
  const tableBody = document.getElementById('image-port-table').getElementsByTagName('tbody')[0];
  tableBody.innerHTML = ''; // Clear existing rows

  containersData.forEach(container => {
    const row = document.createElement('tr');
    const imageCell = document.createElement('td');
    const hostPortCell = document.createElement('td');
    const dockerPortCell = document.createElement('td');
    const dockerNetworkCell = document.createElement('td');
    const createdCell = document.createElement('td');

    imageCell.textContent = container.image;
    hostPortCell.textContent = container.host_ports;
    dockerPortCell.textContent = container.docker_ports;
    dockerNetworkCell.textContent = container.network;
    createdCell.textContent = new Date(container.created).toLocaleString();

    row.appendChild(imageCell);
    row.appendChild(hostPortCell);
    row.appendChild(dockerPortCell);
    row.appendChild(dockerNetworkCell);
    row.appendChild(createdCell);
    tableBody.appendChild(row);
  });

  // Initialize DataTables with custom sorting for host and docker ports, network, and created columns
  if ($.fn.DataTable.isDataTable('#image-port-table')) {
    $('#image-port-table').DataTable().clear().rows.add(containersData).draw();
  } else {
    $('#image-port-table').DataTable({
      pageLength: 25,
      columnDefs: [
        {
          targets: [1, 2], // Host Port and Docker Port columns
          type: 'port-sort'
        },
        {
          targets: 3, // Network column
          type: 'network-sort'
        },
        {
          targets: 4, // Created column
          type: 'date'
        }
      ]
    });
  }
}

// Custom sorting function for ports
$.fn.dataTable.ext.type.order['port-sort-pre'] = function(data) {
  if (data) {
    const firstPort = data.split(',')[0];
    if (firstPort === 'None') {
      return Number.MAX_SAFE_INTEGER; // Move 'None' to the end of the sort
    }
    const portNumber = firstPort.split('/')[0];
    return parseInt(portNumber, 10);
  }
  return Number.MAX_SAFE_INTEGER; // Handle empty or malformed data
};

// Custom sorting function for network
$.fn.dataTable.ext.type.order['network-sort-pre'] = function(data) {
  if (data === 'host') {
    return Number.MAX_SAFE_INTEGER; // Move 'host' to the end of the sort
  }
  return data;
};

async function fetchContainers() {
  try {
    const response = await fetch('/api/containers');
    const containersData = await response.json();
    populateTable(containersData);
  } catch (error) {
    console.error('Error fetching containers:', error);
  }
}

document.addEventListener('DOMContentLoaded', fetchContainers);